#!/usr/bin/env python
import argparse
from datetime import datetime
from siriuscommon.zabbix import ZabbixClient


if __name__ == "__main__":
    fmt = "%d/%m/%Y %H:%M"
    _fmt = fmt.replace("%", "")
    parser = argparse.ArgumentParser("List zabbix item trend")
    parser.add_argument("itemid", help="item id")
    parser.add_argument("tini", help=f"tIni {_fmt}")
    parser.add_argument("tend", help=f"tEnd {_fmt}")
    parser.add_argument("--user", "-u", help="zabbix user", required=True)
    parser.add_argument("--password", "-p", help="zabbix password", required=True)

    args = parser.parse_args()

    itemid = args.itemid.strip()
    tini = datetime.strptime(args.tini, fmt)
    tend = datetime.strptime(args.tend, fmt)

    client = ZabbixClient(user=args.user, password=args.password)
    res = client.get_item_trends(itemid, tini, tend)

    print("item.value; timestamp")
    for item in res:
        print(
            f"{item.value_min}; {item.value_avg}; {item.value_max}; {item.num}; {item.timestamp}"
        )



import logging as _logging
import typing as _typing

__version__ = "0.0.1"
__author__ = "Carneiro, Claudio F."
__date__ = "Thu, 05 Aug 2021 09:38:36 -0300"


def get_logger(
    name=__file__,
    level: int = _logging.WARNING,
    handlers: _typing.Optional[_typing.List[_logging.Handler]] = None,
) -> _logging.Logger:
    """Returns a logger object"""

    logger = _logging.getLogger(name)

    if not len(logger.handlers) and not handlers:
        formatter = _logging.Formatter(
            "[%(asctime)s %(levelname)s %(filename)s:%(lineno)s - %(funcName)s] %(message)s"
        )
        logger.setLevel(level)
        console = _logging.StreamHandler()
        console.setFormatter(formatter)
        logger.addHandler(console)
    return logger



#!/usr/bin/env python
import requests as _requests
import logging as _logging
import typing as _typing

from .. import get_logger

_logger = get_logger(level=_logging.INFO)
TIMEFMT = "%d/%m/%Y %H:%M:%S"
API_CANDIDATES = [
    "10.0.38.42:26001",
    "10.0.38.46:26001",
    "10.0.38.59:26001",
    "localhost:8080",
]
_TIMEOUT = 5


class RemoteAPI(Exception):
    pass


def checkCandidates() -> str:
    for ip in API_CANDIDATES:
        url = "http://{}".format(ip)
        try:
            if _requests.get(url + "/status", timeout=2).text == "Healthy!":
                _logger.info('Using remote url "{}"'.format(url))
                return url + "/devices"
        except:
            _logger.warning('Remote url "{}" unavailable'.format(url))
            pass
    raise RemoteAPI("No remote API available")


def getMBTemp() -> _typing.List[dict]:
    """MBTemp json from upstream @return dict following the data_model pattern"""
    return _requests.get(
        checkCandidates(), verify=False, params={"type": "mbtemp"}, timeout=_TIMEOUT
    ).json()


def getMKS() -> _typing.List[dict]:
    """MKS json from upstream @return dict following the data_model pattern"""
    return _requests.get(
        checkCandidates(), verify=False, params={"type": "mks"}, timeout=_TIMEOUT
    ).json()


def getAgilent() -> _typing.List[dict]:
    """Agilent json from upstream @return dict following the data_model pattern"""
    return _requests.get(
        checkCandidates(), verify=False, params={"type": "agilent"}, timeout=_TIMEOUT
    ).json()


def getDevicesDict(data: dict) -> _typing.Iterable[dict]:
    """Device generator from json"""
    for ip, beagle in data.items():
        for device in beagle:
            yield device


def getChannelsDict(data: dict) -> _typing.Iterable[_typing.Tuple[str, str, dict]]:
    """Tuple of (device prefix, channel_name, channel_data) generator from json"""
    for ip, beagle in data.items():
        for device in beagle:
            for channel_name, channel_data in device["channels"].items():
                yield device["prefix"], channel_name, channel_data


if __name__ == "__main__":
    # for ip, dev in getAgilent().items():
    data = getAgilent()
    for device, channel_name, channel_data in getChannelsDict(data):
        print(device, channel_name, channel_data["prefix"])



#!/usr/bin/env python3

import unittest
import os
from conscommon.spreadsheet import SheetName
import conscommon.spreadsheet.parser as spreadsheet_parser


class TestDataModel(unittest.TestCase):
    def test_spreadsheetParser(self):
        spreadsheet_path = os.path.join(
            os.path.dirname(os.path.abspath(__file__)), "Redes e Beaglebones.xlsx"
        )
        self.assertIs(os.path.exists(spreadsheet_path), True)
        data = spreadsheet_parser.loadSheets(spreadsheet_path)

        self.assertIsNot(data[SheetName.AGILENT].__len__(), 0)
        self.assertIsNot(data[SheetName.MKS].__len__(), 0)
        self.assertIsNot(data[SheetName.MBTEMP].__len__(), 0)


if __name__ == "__main__":
    unittest.main()



import requests as _requests
import typing as _typing

from .types import (
    ArchiverDisconnectedPV,
    ArchiverPausedPV,
    _make_archiver_disconnected_pv,
    _make_archiver_paused_pv,
    _make_archiver_status_pv,
)

_default_base_url = "https://10.0.38.42"


class ArchiverLoginException(Exception):
    def __init__(self, *args: object) -> None:
        super().__init__(*args)


class ArchiverClient:
    def __init__(
        self,
        base_url: str = _default_base_url,
        username: _typing.Optional[str] = None,
        password: _typing.Optional[str] = None,
    ) -> None:

        self._mgmt_url = f"{base_url}/mgmt/bpl"
        self._authenticated = False

        self._session: _requests.Session = _requests.Session()

        if username and password:
            self.login(username, password)

    def login(self, username: str, password: str):
        data = {"username": username, "password": password}

        response = self._session.post(
            f"{self._mgmt_url}/login", data=data, verify=False
        )
        self._authenticated = (
            response.status_code == 200 and "authenticated" in response.text
        )
        if not self.authenticated:
            raise ArchiverLoginException(f"failed to authenticat user {username}")

    def pause_pv(self, pv_name: str):
        if not self.authenticated:
            raise ArchiverLoginException("operation requires authentication")

        if not pv_name:
            raise ValueError()

        response = self._session.get(f"{self._mgmt_url}/pauseArchivingPV?pv={pv_name}")
        if (
            response.status_code == 200
            and (f"Successfully paused the archiving of PV {pv_name}")
            or (f"PV {pv_name} is already paused") in response.text
        ):
            return True
        return False

    @property
    def authenticated(self):
        return self._authenticated


def getCurrentlyDisconnectedPVs(
    base_url: str = _default_base_url,
) -> _typing.List[ArchiverDisconnectedPV]:
    return [
        _make_archiver_disconnected_pv(**pv)
        for pv in _requests.get(
            f"{base_url}/mgmt/bpl/getCurrentlyDisconnectedPVs", verify=False
        ).json()
    ]


def getPausedPVsReport(
    base_url: str = _default_base_url,
) -> _typing.List[ArchiverPausedPV]:
    return [
        _make_archiver_paused_pv(**pv)
        for pv in _requests.get(
            f"{base_url}/mgmt/bpl/getPausedPVsReport", verify=False
        ).json()
    ]


def getMatchingPVs(search: str, base_url: str = _default_base_url) -> _typing.List[str]:
    return [
        pv
        for pv in _requests.get(
            f"{base_url}/retrieval/bpl/getMatchingPVs?pv={search}&limit=500",
            verify=False,
        ).json()
    ]


def getPVStatus(search: str, base_url: str = _default_base_url):
    return [
        _make_archiver_status_pv(**pv)
        for pv in _requests.get(
            f"{base_url}/mgmt/bpl/getPVStatus",
            params={"pv": search, "reporttype": "short"},
            verify=False,
        ).json()
    ]



import logging as _logging
import typing as _typing
import requests as _requests
from datetime import datetime as _datetime
from pyzabbix import ZabbixAPI as _ZabbixAPI

from .. import get_logger
from .types import ZabbixHistory, ZabbixTrend, _make_zabbix_history, _make_zabbix_trend

_logger = get_logger(__name__)


class ZabbixItem(object):
    def __init__(
        self,
        data,
    ) -> None:
        self,
        self.itemid: str = data["itemid"]
        self.value_type: int = int(data["value_type"])
        self.hostid: str = data["hostid"]
        self.name: str = data["name"]
        self.lastvalue: _typing.Any = data["lastvalue"]
        self.key_: str = data["key_"]
        self.data = data

    def __str__(self) -> str:
        return str(self.data)


class ZabbixClient:
    def __init__(
        self, user: str, password: str, server: str = "https://10.0.38.46:20093"
    ) -> None:

        self._session = _requests.Session()
        self._session.verify = False
        self._api: _ZabbixAPI = _ZabbixAPI(server=server, session=self._session)
        self._api.login(
            user=user,
            password=password,
        )

    def get_item(self, itemid: str) -> _typing.Optional[ZabbixItem]:
        response = self._api.do_request(
            method="item.get",
            params={
                "itemids": itemid,
            },
        )
        result = response["result"]
        if len(result) == 1:
            return ZabbixItem(result[0])
        else:
            return None

    def get_items_from_host(self, host: str) -> _typing.List[ZabbixItem]:
        response = self._api.do_request(
            method="item.get",
            params={
                "host": host,
            },
        )
        return [ZabbixItem(data) for data in response["result"]]

    def get_item_trends(
        self,
        itemid: str,
        time_from: _typing.Optional[_datetime] = None,
        time_till: _typing.Optional[_datetime] = None,
    ) -> _typing.List[ZabbixTrend]:
        item = self.get_item(itemid=itemid)
        if not item:
            raise Exception("Item not found")

        payload: _typing.Dict[str, _typing.Union[str, int, _typing.List]] = {
            "itemids": itemid,
            "sortfield": "clock",
            "output": [
                "itemid",
                "clock",
                "num",
                "value_avg",
                "value_min",
                "value_max",
            ],
            "history": item.value_type,
        }
        if time_from:
            payload["time_from"] = int(time_from.timestamp())

        if time_till:
            payload["time_till"] = int(time_till.timestamp())

        response = self._api.do_request("trend.get", payload)
        return [_make_zabbix_trend(data) for data in response["result"]]

    def get_item_history(
        self,
        itemid: str,
        time_from: _typing.Optional[_datetime] = None,
        time_till: _typing.Optional[_datetime] = None,
    ) -> _typing.List[ZabbixHistory]:
        item = self.get_item(itemid=itemid)
        if not item:
            raise Exception("Item not found")

        payload: _typing.Dict[str, _typing.Union[str, int]] = {
            "itemids": itemid,
            "sortfield": "clock",
            "output": "extend",
            "history": item.value_type,
        }
        if time_from:
            payload["time_from"] = int(time_from.timestamp())

        if time_till:
            payload["time_till"] = int(time_till.timestamp())

        response = self._api.do_request("history.get", payload)
        return [_make_zabbix_history(data) for data in response["result"]]



#!/usr/bin/env python
from setuptools import setup, find_packages
import pkg_resources

from src.siriuscommon import __version__, __author__


def get_abs_path(relative):
    return pkg_resources.resource_filename(__name__, relative)


def get_long_description() -> str:
    desc = ""
    with open(get_abs_path("README.md"), "r") as _f:
        desc += _f.read().strip()

    desc += "\n\n"

    with open(get_abs_path("CHANGES.md"), "r") as _f:
        desc += _f.read().strip()

    return desc


long_description = get_long_description()


with open(get_abs_path("requirements.txt"), "r") as _f:
    requirements = _f.readlines()

setup(
    author=__author__,
    classifiers=[
        "Intended Audience :: Science/Research",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python",
        "Topic :: Scientific/Engineering",
    ],
    description="Commons for Sirius applications",
    download_url="https://github.com/lnls-sirius/sirius-common",
    install_requires=requirements,
    include_package_data=True,
    license="GNU GPLv3",
    long_description=long_description,
    long_description_content_type="text/markdown",
    name="siriuscommon",
    packages=find_packages(
        where="src",
        include=[
            "siriuscommon*",
        ],
    ),
    scripts=[
        "scripts/archiver-get-pv-status.py",
        "scripts/archiver-get-pvs-disconnected.py",
        "scripts/archiver-get-pvs-matching.py",
        "scripts/archiver-get-pvs-paused.py",
        "scripts/zabbix-get-item-history.py",
        "scripts/zabbix-get-item-trend.py",
        "scripts/zabbix-get-items-from-host.py",
    ],
    package_dir={"": "src"},
    python_requires=">=3.6",
    url="https://github.com/lnls-sirius/sirius-common/",
    version=__version__,
    zip_safe=True,
)



#!/usr/bin/env python
import argparse
from siriuscommon.archiver import getPVStatus

if __name__ == "__main__":
    parser = argparse.ArgumentParser("getPVStatus Request")
    parser.add_argument("search", type=str, help="search glob pattern")
    args = parser.parse_args()
    status = getPVStatus(search=args.search)
    print(status)
